@@ -43,6 +43,21 @@ const_iv(MISALIGNED_SUB_BUFFER_OFFSET)
 #ifdef CL_EXEC_STATUS_ERROR_FOR_EVENTS_IN_WAIT_LIST
 const_iv(EXEC_STATUS_ERROR_FOR_EVENTS_IN_WAIT_LIST)
 #endif
+#ifdef CL_COMPILE_PROGRAM_FAILURE
+const_iv(COMPILE_PROGRAM_FAILURE)
+#endif
+#ifdef CL_LINKER_NOT_AVAILABLE
+const_iv(LINKER_NOT_AVAILABLE)
+#endif
+#ifdef CL_LINK_PROGRAM_FAILURE
+const_iv(LINK_PROGRAM_FAILURE)
+#endif
+#ifdef CL_DEVICE_PARTITION_FAILED
+const_iv(DEVICE_PARTITION_FAILED)
+#endif
+#ifdef CL_KERNEL_ARG_INFO_NOT_AVAILABLE
+const_iv(KERNEL_ARG_INFO_NOT_AVAILABLE)
+#endif
 #ifdef CL_INVALID_VALUE
 const_iv(INVALID_VALUE)
 #endif
@@ -148,18 +163,39 @@ const_iv(INVALID_GLOBAL_WORK_SIZE)
 #ifdef CL_INVALID_PROPERTY
 const_iv(INVALID_PROPERTY)
 #endif
+#ifdef CL_INVALID_IMAGE_DESCRIPTOR
+const_iv(INVALID_IMAGE_DESCRIPTOR)
+#endif
+#ifdef CL_INVALID_COMPILER_OPTIONS
+const_iv(INVALID_COMPILER_OPTIONS)
+#endif
+#ifdef CL_INVALID_LINKER_OPTIONS
+const_iv(INVALID_LINKER_OPTIONS)
+#endif
+#ifdef CL_INVALID_DEVICE_PARTITION_COUNT
+const_iv(INVALID_DEVICE_PARTITION_COUNT)
+#endif
 #ifdef CL_VERSION_1_0
 const_iv(VERSION_1_0)
 #endif
 #ifdef CL_VERSION_1_1
 const_iv(VERSION_1_1)
 #endif
+#ifdef CL_VERSION_1_2
+const_iv(VERSION_1_2)
+#endif
 #ifdef CL_FALSE
 const_iv(FALSE)
 #endif
 #ifdef CL_TRUE
 const_iv(TRUE)
 #endif
+#ifdef CL_BLOCKING
+const_iv(BLOCKING)
+#endif
+#ifdef CL_NON_BLOCKING
+const_iv(NON_BLOCKING)
+#endif
 #ifdef CL_PLATFORM_PROFILE
 const_iv(PLATFORM_PROFILE)
 #endif
@@ -187,6 +223,9 @@ const_iv(DEVICE_TYPE_GPU)
 #ifdef CL_DEVICE_TYPE_ACCELERATOR
 const_iv(DEVICE_TYPE_ACCELERATOR)
 #endif
+#ifdef CL_DEVICE_TYPE_CUSTOM
+const_iv(DEVICE_TYPE_CUSTOM)
+#endif
 #ifdef CL_DEVICE_TYPE_ALL
 const_iv(DEVICE_TYPE_ALL)
 #endif
@@ -340,6 +379,9 @@ const_iv(DEVICE_EXTENSIONS)
 #ifdef CL_DEVICE_PLATFORM
 const_iv(DEVICE_PLATFORM)
 #endif
+#ifdef CL_DEVICE_DOUBLE_FP_CONFIG
+const_iv(DEVICE_DOUBLE_FP_CONFIG)
+#endif
 #ifdef CL_DEVICE_PREFERRED_VECTOR_WIDTH_HALF
 const_iv(DEVICE_PREFERRED_VECTOR_WIDTH_HALF)
 #endif
@@ -370,6 +412,42 @@ const_iv(DEVICE_NATIVE_VECTOR_WIDTH_HALF)
 #ifdef CL_DEVICE_OPENCL_C_VERSION
 const_iv(DEVICE_OPENCL_C_VERSION)
 #endif
+#ifdef CL_DEVICE_LINKER_AVAILABLE
+const_iv(DEVICE_LINKER_AVAILABLE)
+#endif
+#ifdef CL_DEVICE_BUILT_IN_KERNELS
+const_iv(DEVICE_BUILT_IN_KERNELS)
+#endif
+#ifdef CL_DEVICE_IMAGE_MAX_BUFFER_SIZE
+const_iv(DEVICE_IMAGE_MAX_BUFFER_SIZE)
+#endif
+#ifdef CL_DEVICE_IMAGE_MAX_ARRAY_SIZE
+const_iv(DEVICE_IMAGE_MAX_ARRAY_SIZE)
+#endif
+#ifdef CL_DEVICE_PARENT_DEVICE
+const_iv(DEVICE_PARENT_DEVICE)
+#endif
+#ifdef CL_DEVICE_PARTITION_MAX_SUB_DEVICES
+const_iv(DEVICE_PARTITION_MAX_SUB_DEVICES)
+#endif
+#ifdef CL_DEVICE_PARTITION_PROPERTIES
+const_iv(DEVICE_PARTITION_PROPERTIES)
+#endif
+#ifdef CL_DEVICE_PARTITION_AFFINITY_DOMAIN
+const_iv(DEVICE_PARTITION_AFFINITY_DOMAIN)
+#endif
+#ifdef CL_DEVICE_PARTITION_TYPE
+const_iv(DEVICE_PARTITION_TYPE)
+#endif
+#ifdef CL_DEVICE_REFERENCE_COUNT
+const_iv(DEVICE_REFERENCE_COUNT)
+#endif
+#ifdef CL_DEVICE_PREFERRED_INTEROP_USER_SYNC
+const_iv(DEVICE_PREFERRED_INTEROP_USER_SYNC)
+#endif
+#ifdef CL_DEVICE_PRINTF_BUFFER_SIZE
+const_iv(DEVICE_PRINTF_BUFFER_SIZE)
+#endif
 #ifdef CL_FP_DENORM
 const_iv(FP_DENORM)
 #endif
@@ -391,6 +469,9 @@ const_iv(FP_FMA)
 #ifdef CL_FP_SOFT_FLOAT
 const_iv(FP_SOFT_FLOAT)
 #endif
+#ifdef CL_FP_CORRECTLY_ROUNDED_DIVIDE_SQRT
+const_iv(FP_CORRECTLY_ROUNDED_DIVIDE_SQRT)
+#endif
 #ifdef CL_NONE
 const_iv(NONE)
 #endif
@@ -433,6 +514,39 @@ const_iv(CONTEXT_NUM_DEVICES)
 #ifdef CL_CONTEXT_PLATFORM
 const_iv(CONTEXT_PLATFORM)
 #endif
+#ifdef CL_CONTEXT_INTEROP_USER_SYNC
+const_iv(CONTEXT_INTEROP_USER_SYNC)
+#endif
+#ifdef CL_DEVICE_PARTITION_EQUALLY
+const_iv(DEVICE_PARTITION_EQUALLY)
+#endif
+#ifdef CL_DEVICE_PARTITION_BY_COUNTS
+const_iv(DEVICE_PARTITION_BY_COUNTS)
+#endif
+#ifdef CL_DEVICE_PARTITION_BY_COUNTS_LIST_END
+const_iv(DEVICE_PARTITION_BY_COUNTS_LIST_END)
+#endif
+#ifdef CL_DEVICE_PARTITION_BY_AFFINITY_DOMAIN
+const_iv(DEVICE_PARTITION_BY_AFFINITY_DOMAIN)
+#endif
+#ifdef CL_DEVICE_AFFINITY_DOMAIN_NUMA
+const_iv(DEVICE_AFFINITY_DOMAIN_NUMA)
+#endif
+#ifdef CL_DEVICE_AFFINITY_DOMAIN_L4_CACHE
+const_iv(DEVICE_AFFINITY_DOMAIN_L4_CACHE)
+#endif
+#ifdef CL_DEVICE_AFFINITY_DOMAIN_L3_CACHE
+const_iv(DEVICE_AFFINITY_DOMAIN_L3_CACHE)
+#endif
+#ifdef CL_DEVICE_AFFINITY_DOMAIN_L2_CACHE
+const_iv(DEVICE_AFFINITY_DOMAIN_L2_CACHE)
+#endif
+#ifdef CL_DEVICE_AFFINITY_DOMAIN_L1_CACHE
+const_iv(DEVICE_AFFINITY_DOMAIN_L1_CACHE)
+#endif
+#ifdef CL_DEVICE_AFFINITY_DOMAIN_NEXT_PARTITIONABLE
+const_iv(DEVICE_AFFINITY_DOMAIN_NEXT_PARTITIONABLE)
+#endif
 #ifdef CL_QUEUE_CONTEXT
 const_iv(QUEUE_CONTEXT)
 #endif
@@ -463,6 +577,21 @@ const_iv(MEM_ALLOC_HOST_PTR)
 #ifdef CL_MEM_COPY_HOST_PTR
 const_iv(MEM_COPY_HOST_PTR)
 #endif
+#ifdef CL_MEM_HOST_WRITE_ONLY
+const_iv(MEM_HOST_WRITE_ONLY)
+#endif
+#ifdef CL_MEM_HOST_READ_ONLY
+const_iv(MEM_HOST_READ_ONLY)
+#endif
+#ifdef CL_MEM_HOST_NO_ACCESS
+const_iv(MEM_HOST_NO_ACCESS)
+#endif
+#ifdef CL_MIGRATE_MEM_OBJECT_HOST
+const_iv(MIGRATE_MEM_OBJECT_HOST)
+#endif
+#ifdef CL_MIGRATE_MEM_OBJECT_CONTENT_UNDEFINED
+const_iv(MIGRATE_MEM_OBJECT_CONTENT_UNDEFINED)
+#endif
 #ifdef CL_R
 const_iv(R)
 #endif
@@ -556,6 +685,18 @@ const_iv(MEM_OBJECT_IMAGE2D)
 #ifdef CL_MEM_OBJECT_IMAGE3D
 const_iv(MEM_OBJECT_IMAGE3D)
 #endif
+#ifdef CL_MEM_OBJECT_IMAGE2D_ARRAY
+const_iv(MEM_OBJECT_IMAGE2D_ARRAY)
+#endif
+#ifdef CL_MEM_OBJECT_IMAGE1D
+const_iv(MEM_OBJECT_IMAGE1D)
+#endif
+#ifdef CL_MEM_OBJECT_IMAGE1D_ARRAY
+const_iv(MEM_OBJECT_IMAGE1D_ARRAY)
+#endif
+#ifdef CL_MEM_OBJECT_IMAGE1D_BUFFER
+const_iv(MEM_OBJECT_IMAGE1D_BUFFER)
+#endif
 #ifdef CL_MEM_TYPE
 const_iv(MEM_TYPE)
 #endif
@@ -604,6 +745,18 @@ const_iv(IMAGE_HEIGHT)
 #ifdef CL_IMAGE_DEPTH
 const_iv(IMAGE_DEPTH)
 #endif
+#ifdef CL_IMAGE_ARRAY_SIZE
+const_iv(IMAGE_ARRAY_SIZE)
+#endif
+#ifdef CL_IMAGE_BUFFER
+const_iv(IMAGE_BUFFER)
+#endif
+#ifdef CL_IMAGE_NUM_MIP_LEVELS
+const_iv(IMAGE_NUM_MIP_LEVELS)
+#endif
+#ifdef CL_IMAGE_NUM_SAMPLES
+const_iv(IMAGE_NUM_SAMPLES)
+#endif
 #ifdef CL_ADDRESS_NONE
 const_iv(ADDRESS_NONE)
 #endif
@@ -646,6 +799,9 @@ const_iv(MAP_READ)
 #ifdef CL_MAP_WRITE
 const_iv(MAP_WRITE)
 #endif
+#ifdef CL_MAP_WRITE_INVALIDATE_REGION
+const_iv(MAP_WRITE_INVALIDATE_REGION)
+#endif
 #ifdef CL_PROGRAM_REFERENCE_COUNT
 const_iv(PROGRAM_REFERENCE_COUNT)
 #endif
@@ -667,6 +823,12 @@ const_iv(PROGRAM_BINARY_SIZES)
 #ifdef CL_PROGRAM_BINARIES
 const_iv(PROGRAM_BINARIES)
 #endif
+#ifdef CL_PROGRAM_NUM_KERNELS
+const_iv(PROGRAM_NUM_KERNELS)
+#endif
+#ifdef CL_PROGRAM_KERNEL_NAMES
+const_iv(PROGRAM_KERNEL_NAMES)
+#endif
 #ifdef CL_PROGRAM_BUILD_STATUS
 const_iv(PROGRAM_BUILD_STATUS)
 #endif
@@ -676,6 +838,21 @@ const_iv(PROGRAM_BUILD_OPTIONS)
 #ifdef CL_PROGRAM_BUILD_LOG
 const_iv(PROGRAM_BUILD_LOG)
 #endif
+#ifdef CL_PROGRAM_BINARY_TYPE
+const_iv(PROGRAM_BINARY_TYPE)
+#endif
+#ifdef CL_PROGRAM_BINARY_TYPE_NONE
+const_iv(PROGRAM_BINARY_TYPE_NONE)
+#endif
+#ifdef CL_PROGRAM_BINARY_TYPE_COMPILED_OBJECT
+const_iv(PROGRAM_BINARY_TYPE_COMPILED_OBJECT)
+#endif
+#ifdef CL_PROGRAM_BINARY_TYPE_LIBRARY
+const_iv(PROGRAM_BINARY_TYPE_LIBRARY)
+#endif
+#ifdef CL_PROGRAM_BINARY_TYPE_EXECUTABLE
+const_iv(PROGRAM_BINARY_TYPE_EXECUTABLE)
+#endif
 #ifdef CL_BUILD_SUCCESS
 const_iv(BUILD_SUCCESS)
 #endif
@@ -703,6 +880,60 @@ const_iv(KERNEL_CONTEXT)
 #ifdef CL_KERNEL_PROGRAM
 const_iv(KERNEL_PROGRAM)
 #endif
+#ifdef CL_KERNEL_ATTRIBUTES
+const_iv(KERNEL_ATTRIBUTES)
+#endif
+#ifdef CL_KERNEL_ARG_ADDRESS_QUALIFIER
+const_iv(KERNEL_ARG_ADDRESS_QUALIFIER)
+#endif
+#ifdef CL_KERNEL_ARG_ACCESS_QUALIFIER
+const_iv(KERNEL_ARG_ACCESS_QUALIFIER)
+#endif
+#ifdef CL_KERNEL_ARG_TYPE_NAME
+const_iv(KERNEL_ARG_TYPE_NAME)
+#endif
+#ifdef CL_KERNEL_ARG_TYPE_QUALIFIER
+const_iv(KERNEL_ARG_TYPE_QUALIFIER)
+#endif
+#ifdef CL_KERNEL_ARG_NAME
+const_iv(KERNEL_ARG_NAME)
+#endif
+#ifdef CL_KERNEL_ARG_ADDRESS_GLOBAL
+const_iv(KERNEL_ARG_ADDRESS_GLOBAL)
+#endif
+#ifdef CL_KERNEL_ARG_ADDRESS_LOCAL
+const_iv(KERNEL_ARG_ADDRESS_LOCAL)
+#endif
+#ifdef CL_KERNEL_ARG_ADDRESS_CONSTANT
+const_iv(KERNEL_ARG_ADDRESS_CONSTANT)
+#endif
+#ifdef CL_KERNEL_ARG_ADDRESS_PRIVATE
+const_iv(KERNEL_ARG_ADDRESS_PRIVATE)
+#endif
+#ifdef CL_KERNEL_ARG_ACCESS_READ_ONLY
+const_iv(KERNEL_ARG_ACCESS_READ_ONLY)
+#endif
+#ifdef CL_KERNEL_ARG_ACCESS_WRITE_ONLY
+const_iv(KERNEL_ARG_ACCESS_WRITE_ONLY)
+#endif
+#ifdef CL_KERNEL_ARG_ACCESS_READ_WRITE
+const_iv(KERNEL_ARG_ACCESS_READ_WRITE)
+#endif
+#ifdef CL_KERNEL_ARG_ACCESS_NONE
+const_iv(KERNEL_ARG_ACCESS_NONE)
+#endif
+#ifdef CL_KERNEL_ARG_TYPE_NONE
+const_iv(KERNEL_ARG_TYPE_NONE)
+#endif
+#ifdef CL_KERNEL_ARG_TYPE_CONST
+const_iv(KERNEL_ARG_TYPE_CONST)
+#endif
+#ifdef CL_KERNEL_ARG_TYPE_RESTRICT
+const_iv(KERNEL_ARG_TYPE_RESTRICT)
+#endif
+#ifdef CL_KERNEL_ARG_TYPE_VOLATILE
+const_iv(KERNEL_ARG_TYPE_VOLATILE)
+#endif
 #ifdef CL_KERNEL_WORK_GROUP_SIZE
 const_iv(KERNEL_WORK_GROUP_SIZE)
 #endif
@@ -718,6 +949,9 @@ const_iv(KERNEL_PREFERRED_WORK_GROUP_SIZE_MULTIPLE)
 #ifdef CL_KERNEL_PRIVATE_MEM_SIZE
 const_iv(KERNEL_PRIVATE_MEM_SIZE)
 #endif
+#ifdef CL_KERNEL_GLOBAL_WORK_SIZE
+const_iv(KERNEL_GLOBAL_WORK_SIZE)
+#endif
 #ifdef CL_EVENT_COMMAND_QUEUE
 const_iv(EVENT_COMMAND_QUEUE)
 #endif
@@ -796,6 +1030,18 @@ const_iv(COMMAND_COPY_BUFFER_RECT)
 #ifdef CL_COMMAND_USER
 const_iv(COMMAND_USER)
 #endif
+#ifdef CL_COMMAND_BARRIER
+const_iv(COMMAND_BARRIER)
+#endif
+#ifdef CL_COMMAND_MIGRATE_MEM_OBJECTS
+const_iv(COMMAND_MIGRATE_MEM_OBJECTS)
+#endif
+#ifdef CL_COMMAND_FILL_BUFFER
+const_iv(COMMAND_FILL_BUFFER)
+#endif
+#ifdef CL_COMMAND_FILL_IMAGE
+const_iv(COMMAND_FILL_IMAGE)
+#endif
 #ifdef CL_COMPLETE
 const_iv(COMPLETE)
 #endif
@@ -871,6 +1117,18 @@ const_iv(GL_OBJECT_TEXTURE3D)
 #ifdef CL_GL_OBJECT_RENDERBUFFER
 const_iv(GL_OBJECT_RENDERBUFFER)
 #endif
+#ifdef CL_GL_OBJECT_TEXTURE2D_ARRAY
+const_iv(GL_OBJECT_TEXTURE2D_ARRAY)
+#endif
+#ifdef CL_GL_OBJECT_TEXTURE1D
+const_iv(GL_OBJECT_TEXTURE1D)
+#endif
+#ifdef CL_GL_OBJECT_TEXTURE1D_ARRAY
+const_iv(GL_OBJECT_TEXTURE1D_ARRAY)
+#endif
+#ifdef CL_GL_OBJECT_TEXTURE_BUFFER
+const_iv(GL_OBJECT_TEXTURE_BUFFER)
+#endif
 #ifdef CL_GL_TEXTURE_TARGET
 const_iv(GL_TEXTURE_TARGET)
 #endif
