@@ -166,6 +166,9 @@ const_iv(DEVICE_EXTENSIONS)
 #ifdef CL_DEVICE_PLATFORM
 const_iv(DEVICE_PLATFORM)
 #endif
+#ifdef CL_DEVICE_DOUBLE_FP_CONFIG
+const_iv(DEVICE_DOUBLE_FP_CONFIG)
+#endif
 #ifdef CL_DEVICE_PREFERRED_VECTOR_WIDTH_HALF
 const_iv(DEVICE_PREFERRED_VECTOR_WIDTH_HALF)
 #endif
@@ -196,6 +199,42 @@ const_iv(DEVICE_NATIVE_VECTOR_WIDTH_HALF)
 #ifdef CL_DEVICE_OPENCL_C_VERSION
 const_iv(DEVICE_OPENCL_C_VERSION)
 #endif
+#ifdef CL_DEVICE_LINKER_AVAILABLE
+const_iv(DEVICE_LINKER_AVAILABLE)
+#endif
+#ifdef CL_DEVICE_BUILT_IN_KERNELS
+const_iv(DEVICE_BUILT_IN_KERNELS)
+#endif
+#ifdef CL_DEVICE_IMAGE_MAX_BUFFER_SIZE
+const_iv(DEVICE_IMAGE_MAX_BUFFER_SIZE)
+#endif
+#ifdef CL_DEVICE_IMAGE_MAX_ARRAY_SIZE
+const_iv(DEVICE_IMAGE_MAX_ARRAY_SIZE)
+#endif
+#ifdef CL_DEVICE_PARENT_DEVICE
+const_iv(DEVICE_PARENT_DEVICE)
+#endif
+#ifdef CL_DEVICE_PARTITION_MAX_SUB_DEVICES
+const_iv(DEVICE_PARTITION_MAX_SUB_DEVICES)
+#endif
+#ifdef CL_DEVICE_PARTITION_PROPERTIES
+const_iv(DEVICE_PARTITION_PROPERTIES)
+#endif
+#ifdef CL_DEVICE_PARTITION_AFFINITY_DOMAIN
+const_iv(DEVICE_PARTITION_AFFINITY_DOMAIN)
+#endif
+#ifdef CL_DEVICE_PARTITION_TYPE
+const_iv(DEVICE_PARTITION_TYPE)
+#endif
+#ifdef CL_DEVICE_REFERENCE_COUNT
+const_iv(DEVICE_REFERENCE_COUNT)
+#endif
+#ifdef CL_DEVICE_PREFERRED_INTEROP_USER_SYNC
+const_iv(DEVICE_PREFERRED_INTEROP_USER_SYNC)
+#endif
+#ifdef CL_DEVICE_PRINTF_BUFFER_SIZE
+const_iv(DEVICE_PRINTF_BUFFER_SIZE)
+#endif
 #ifdef CL_CONTEXT_REFERENCE_COUNT
 const_iv(CONTEXT_REFERENCE_COUNT)
 #endif
@@ -211,6 +250,18 @@ const_iv(CONTEXT_NUM_DEVICES)
 #ifdef CL_CONTEXT_PLATFORM
 const_iv(CONTEXT_PLATFORM)
 #endif
+#ifdef CL_CONTEXT_INTEROP_USER_SYNC
+const_iv(CONTEXT_INTEROP_USER_SYNC)
+#endif
+#ifdef CL_DEVICE_PARTITION_EQUALLY
+const_iv(DEVICE_PARTITION_EQUALLY)
+#endif
+#ifdef CL_DEVICE_PARTITION_BY_COUNTS
+const_iv(DEVICE_PARTITION_BY_COUNTS)
+#endif
+#ifdef CL_DEVICE_PARTITION_BY_AFFINITY_DOMAIN
+const_iv(DEVICE_PARTITION_BY_AFFINITY_DOMAIN)
+#endif
 #ifdef CL_QUEUE_CONTEXT
 const_iv(QUEUE_CONTEXT)
 #endif
@@ -316,6 +367,18 @@ const_iv(MEM_OBJECT_IMAGE2D)
 #ifdef CL_MEM_OBJECT_IMAGE3D
 const_iv(MEM_OBJECT_IMAGE3D)
 #endif
+#ifdef CL_MEM_OBJECT_IMAGE2D_ARRAY
+const_iv(MEM_OBJECT_IMAGE2D_ARRAY)
+#endif
+#ifdef CL_MEM_OBJECT_IMAGE1D
+const_iv(MEM_OBJECT_IMAGE1D)
+#endif
+#ifdef CL_MEM_OBJECT_IMAGE1D_ARRAY
+const_iv(MEM_OBJECT_IMAGE1D_ARRAY)
+#endif
+#ifdef CL_MEM_OBJECT_IMAGE1D_BUFFER
+const_iv(MEM_OBJECT_IMAGE1D_BUFFER)
+#endif
 #ifdef CL_MEM_TYPE
 const_iv(MEM_TYPE)
 #endif
@@ -364,6 +427,18 @@ const_iv(IMAGE_HEIGHT)
 #ifdef CL_IMAGE_DEPTH
 const_iv(IMAGE_DEPTH)
 #endif
+#ifdef CL_IMAGE_ARRAY_SIZE
+const_iv(IMAGE_ARRAY_SIZE)
+#endif
+#ifdef CL_IMAGE_BUFFER
+const_iv(IMAGE_BUFFER)
+#endif
+#ifdef CL_IMAGE_NUM_MIP_LEVELS
+const_iv(IMAGE_NUM_MIP_LEVELS)
+#endif
+#ifdef CL_IMAGE_NUM_SAMPLES
+const_iv(IMAGE_NUM_SAMPLES)
+#endif
 #ifdef CL_ADDRESS_NONE
 const_iv(ADDRESS_NONE)
 #endif
@@ -421,6 +496,12 @@ const_iv(PROGRAM_BINARY_SIZES)
 #ifdef CL_PROGRAM_BINARIES
 const_iv(PROGRAM_BINARIES)
 #endif
+#ifdef CL_PROGRAM_NUM_KERNELS
+const_iv(PROGRAM_NUM_KERNELS)
+#endif
+#ifdef CL_PROGRAM_KERNEL_NAMES
+const_iv(PROGRAM_KERNEL_NAMES)
+#endif
 #ifdef CL_PROGRAM_BUILD_STATUS
 const_iv(PROGRAM_BUILD_STATUS)
 #endif
@@ -430,6 +511,9 @@ const_iv(PROGRAM_BUILD_OPTIONS)
 #ifdef CL_PROGRAM_BUILD_LOG
 const_iv(PROGRAM_BUILD_LOG)
 #endif
+#ifdef CL_PROGRAM_BINARY_TYPE
+const_iv(PROGRAM_BINARY_TYPE)
+#endif
 #ifdef CL_KERNEL_FUNCTION_NAME
 const_iv(KERNEL_FUNCTION_NAME)
 #endif
@@ -445,6 +529,48 @@ const_iv(KERNEL_CONTEXT)
 #ifdef CL_KERNEL_PROGRAM
 const_iv(KERNEL_PROGRAM)
 #endif
+#ifdef CL_KERNEL_ATTRIBUTES
+const_iv(KERNEL_ATTRIBUTES)
+#endif
+#ifdef CL_KERNEL_ARG_ADDRESS_QUALIFIER
+const_iv(KERNEL_ARG_ADDRESS_QUALIFIER)
+#endif
+#ifdef CL_KERNEL_ARG_ACCESS_QUALIFIER
+const_iv(KERNEL_ARG_ACCESS_QUALIFIER)
+#endif
+#ifdef CL_KERNEL_ARG_TYPE_NAME
+const_iv(KERNEL_ARG_TYPE_NAME)
+#endif
+#ifdef CL_KERNEL_ARG_TYPE_QUALIFIER
+const_iv(KERNEL_ARG_TYPE_QUALIFIER)
+#endif
+#ifdef CL_KERNEL_ARG_NAME
+const_iv(KERNEL_ARG_NAME)
+#endif
+#ifdef CL_KERNEL_ARG_ADDRESS_GLOBAL
+const_iv(KERNEL_ARG_ADDRESS_GLOBAL)
+#endif
+#ifdef CL_KERNEL_ARG_ADDRESS_LOCAL
+const_iv(KERNEL_ARG_ADDRESS_LOCAL)
+#endif
+#ifdef CL_KERNEL_ARG_ADDRESS_CONSTANT
+const_iv(KERNEL_ARG_ADDRESS_CONSTANT)
+#endif
+#ifdef CL_KERNEL_ARG_ADDRESS_PRIVATE
+const_iv(KERNEL_ARG_ADDRESS_PRIVATE)
+#endif
+#ifdef CL_KERNEL_ARG_ACCESS_READ_ONLY
+const_iv(KERNEL_ARG_ACCESS_READ_ONLY)
+#endif
+#ifdef CL_KERNEL_ARG_ACCESS_WRITE_ONLY
+const_iv(KERNEL_ARG_ACCESS_WRITE_ONLY)
+#endif
+#ifdef CL_KERNEL_ARG_ACCESS_READ_WRITE
+const_iv(KERNEL_ARG_ACCESS_READ_WRITE)
+#endif
+#ifdef CL_KERNEL_ARG_ACCESS_NONE
+const_iv(KERNEL_ARG_ACCESS_NONE)
+#endif
 #ifdef CL_KERNEL_WORK_GROUP_SIZE
 const_iv(KERNEL_WORK_GROUP_SIZE)
 #endif
@@ -460,6 +586,9 @@ const_iv(KERNEL_PREFERRED_WORK_GROUP_SIZE_MULTIPLE)
 #ifdef CL_KERNEL_PRIVATE_MEM_SIZE
 const_iv(KERNEL_PRIVATE_MEM_SIZE)
 #endif
+#ifdef CL_KERNEL_GLOBAL_WORK_SIZE
+const_iv(KERNEL_GLOBAL_WORK_SIZE)
+#endif
 #ifdef CL_EVENT_COMMAND_QUEUE
 const_iv(EVENT_COMMAND_QUEUE)
 #endif
@@ -538,6 +667,18 @@ const_iv(COMMAND_COPY_BUFFER_RECT)
 #ifdef CL_COMMAND_USER
 const_iv(COMMAND_USER)
 #endif
+#ifdef CL_COMMAND_BARRIER
+const_iv(COMMAND_BARRIER)
+#endif
+#ifdef CL_COMMAND_MIGRATE_MEM_OBJECTS
+const_iv(COMMAND_MIGRATE_MEM_OBJECTS)
+#endif
+#ifdef CL_COMMAND_FILL_BUFFER
+const_iv(COMMAND_FILL_BUFFER)
+#endif
+#ifdef CL_COMMAND_FILL_IMAGE
+const_iv(COMMAND_FILL_IMAGE)
+#endif
 #ifdef CL_BUFFER_CREATE_TYPE_REGION
 const_iv(BUFFER_CREATE_TYPE_REGION)
 #endif
@@ -598,6 +739,18 @@ const_iv(GL_OBJECT_TEXTURE3D)
 #ifdef CL_GL_OBJECT_RENDERBUFFER
 const_iv(GL_OBJECT_RENDERBUFFER)
 #endif
+#ifdef CL_GL_OBJECT_TEXTURE2D_ARRAY
+const_iv(GL_OBJECT_TEXTURE2D_ARRAY)
+#endif
+#ifdef CL_GL_OBJECT_TEXTURE1D
+const_iv(GL_OBJECT_TEXTURE1D)
+#endif
+#ifdef CL_GL_OBJECT_TEXTURE1D_ARRAY
+const_iv(GL_OBJECT_TEXTURE1D_ARRAY)
+#endif
+#ifdef CL_GL_OBJECT_TEXTURE_BUFFER
+const_iv(GL_OBJECT_TEXTURE_BUFFER)
+#endif
 #ifdef CL_GL_TEXTURE_TARGET
 const_iv(GL_TEXTURE_TARGET)
 #endif
